function subGraphs=getAllSubGraphs(model,directed)
% getAllSubGraphs
%   Get all metabolic subgraphs in a model. Two metabolites 
%   are connected if they share a reaction.
%
%   model         a model structure
%   directed      true if all metabolites must be reached from all other 
%                 metabolites in the subgraph. Probably has little physiological 
%                 meaning (opt, default false)
%
%   subGraphs     a structure with the subgraphs listed in order of the
%                 number of participating metabolites. The elements are
%                 string arrays with the metabolite IDs
%
%   Usage: subGraphs=getAllSubGraphs(model,directed)
%
%   Rasmus Agren, 2013-02-06
%

if nargin<2
    directed=false;
end

%Generate the connectivity graph. Metabolites are connected through
%reactions. This is not a bipartite graph with the reactions.
if directed==false
    G=model.S*model.S';
    G(G~=0)=1;
end

%Get all subgraphs
[S,C]=graphconncomp(G,'Directed',true,'Weak',~directed);

subGraphs=cell(S,1);

for i=1:S
    subGraphs{i}=strcat(model.metNames(C==i),'[',model.comps(model.metComps(C==i)),']');
end
end